/*
 * @(#)SearchChar.java
 *
 * Copyright (c) 2004 masahito suzuki, Inc. All Rights Reserved
 */
package org.maachang.commons.util;

import java.util.HashSet;
import java.util.Iterator;

import org.maachang.commons.exception.InputException;
import org.maachang.commons.util.array.CharArray;


/**
 * char型検索管理.
 * <BR><BR>
 * char型の情報の検索を管理します.
 *
 * @version     1.00, 2004/10/28
 * @author      Masahito Suzuki
 * @since  JRcCommons 1.00
 */
public class SearchChar
{
    /**
     * シングルデータ管理.
     */
    private HashSet m_hash = null ;
    
    /**
     * コンストラクタ.
     */
    public SearchChar()
    {
        this.create() ;
    }
    
    /**
     * ファイナライズ処理定義.
     * <BR><BR>
     * ファイナライズ処理定義.
     * @exception Exception 例外処理が返されます.
     */
    protected final void finalize() throws Exception
    {
        try{
            this.clear() ;
        }catch( Exception t ){
        }
    }
    
    /**
     * 情報生成.
     * <BR><BR>
     * 情報を生成します.
     */
    public final void create()
    {
        m_hash = new HashSet() ;
    }
    
    /**
     * 情報クリア.
     * <BR><BR>
     * 情報をクリアします.
     */
    public final void clear()
    {
        if( m_hash != null ){
            m_hash.clear() ;
        }
        m_hash = null ;
    }
    
    /**
     * 情報を追加.
     * <BR><BR>
     * 情報を追加します.
     * <BR>
     * @param el 追加対象の要素情報を設定します.
     */
    public final void add( char el )
    {
        if( m_hash != null ){
            m_hash.add( new Integer( ( int )el ) ) ;
        }
    }
    
    /**
     * 情報を追加.
     * <BR><BR>
     * 情報を追加します.
     * <BR>
     * @param el 追加対象の要素情報を設定します.
     * @exception InputException 入力例外.
     */
    public final void add( String el )
        throws InputException
    {
        if( el == null || el.length() <= 0 ){
            throw new InputException( "引数は存在しません" ) ;
        }
        if( m_hash != null ){
            m_hash.add( new Integer( ( int )el.charAt( 0 ) ) ) ;
        }
    }
    
    /**
     * 情報を削除.
     * <BR><BR>
     * 情報を削除します.
     * <BR>
     * @param el 削除対象の要素情報を設定します.
     */
    public final void remove( char el )
    {
        if( m_hash != null ){
            m_hash.remove( new Integer( ( int )el ) ) ;
        }
    }
    
    /**
     * 情報を削除.
     * <BR><BR>
     * 情報を削除します.
     * <BR>
     * @param el 削除対象の要素情報を設定します.
     * @exception InputException 入力例外.
     */
    public final void remove( String el )
        throws InputException
    {
        if( el == null || el.length() <= 0 ){
            throw new InputException( "引数は存在しません" ) ;
        }
        if( m_hash != null ){
            m_hash.remove( new Integer( ( int )el.charAt( 0 ) ) ) ;
        }
    }
    
    /**
     * 格納情報長を取得.
     * <BR><BR>
     * 格納されている情報長が返されます.
     * <BR>
     * @return int 格納されている情報長が返されます.
     */
    public final int size()
    {
        if( m_hash != null ){
            return m_hash.size() ;
        }
        return 0 ;
    }
    
    /**
     * 格納情報を全て取得.
     * <BR><BR>
     * 格納されている情報を全て取得します.
     * <BR>
     * @return char[] 格納されている全ての要素情報が返されます.
     */
    public final char[] getAll()
    {
        int len ;
        Integer tmp = null ;
        Iterator it = null ;
        CharArray ary = null ;
        char[] ret = null ;
        
        if( m_hash != null ){
            
            it = m_hash.iterator() ;
            if( it != null ){
                ary = new CharArray() ;
                while( it.hasNext() ){
                    
                    if( ( tmp = ( Integer )it.next() ) != null ){
                        
                        ary.add( ( char )( tmp.intValue() & 0x0000ffff ) ) ;
                        
                    }
                    tmp = null ;
                    
                }
                
                if( ( len = ary.size() ) > 0 ){
                    
                    ret = new char[ len ] ;
                    System.arraycopy( ary.getObjects(),0,ret,0,len ) ;
                    ary.clear() ;
                    
                }
            }
            
        }
        
        return ret ;
    }
    
    /**
     * 対象情報が存在するかチェック.
     * <BR><BR>
     * 対象の情報が存在するかチェックします.
     * <BR>
     * @param el チェック対象の情報を設定します.
     * @return boolean チェック結果が返されます.<BR>
     *                 [true]が返された場合情報は存在します.<BR>
     *                 [false]が返された場合情報は存在しません.
     */
    public final boolean isData( char el )
    {
        if( m_hash != null ){
            return m_hash.contains( new Integer( ( int )el ) ) ;
        }
        return false ;
    }
    
    /**
     * 対象情報が存在するかチェック.
     * <BR><BR>
     * 対象の情報が存在するかチェックします.
     * <BR>
     * @param el チェック対象の情報を設定します.
     * @return boolean チェック結果が返されます.<BR>
     *                 [true]が返された場合情報は存在します.<BR>
     *                 [false]が返された場合情報は存在しません.
     */
    public final boolean isData( String el )
    {
        if( el != null && el.length() > 0 && m_hash != null ){
            return m_hash.contains( new Integer( ( int )( el.charAt( 0 ) ) ) ) ;
        }
        return false ;
    }
    
}
